This is an automated email from the ASF dual-hosted git repository.

asf-gitbox-commits pushed a commit to branch geoapi-4.0
in repository https://gitbox.apache.org/repos/asf/sis.git

commit a6b025d1cc9dd2e64c3f0a5c420ce99a0abd3101
Author: Martin Desruisseaux <[email protected]>
AuthorDate: Tue Aug 18 23:44:45 2026 +0200

    Replace "JPMS" by "Java Module" in documentation.
---
 .../sis/buildtools/coding/VerifyVersionInJavadoc.java    |  6 +++---
 .../org/apache/sis/buildtools/gradle/Dependency.java     | 16 +++++++++-------
 .../apache/sis/buildtools/gradle/ModularPublishing.java  |  6 +++---
 .../org/apache/sis/buildtools/gradle/ModularTest.java    |  2 +-
 .../java/org/apache/sis/buildtools/maven/Generator.java  |  6 +++---
 .../transform/DefaultMathTransformFactoryTest.java       |  2 +-
 .../main/org/apache/sis/system/Reflect.java              |  2 +-
 7 files changed, 21 insertions(+), 19 deletions(-)

diff --git 
a/buildSrc/src/main/java/org/apache/sis/buildtools/coding/VerifyVersionInJavadoc.java
 
b/buildSrc/src/main/java/org/apache/sis/buildtools/coding/VerifyVersionInJavadoc.java
index c4cb21c78a..18225f90e4 100644
--- 
a/buildSrc/src/main/java/org/apache/sis/buildtools/coding/VerifyVersionInJavadoc.java
+++ 
b/buildSrc/src/main/java/org/apache/sis/buildtools/coding/VerifyVersionInJavadoc.java
@@ -45,9 +45,9 @@ import java.util.Set;
  * {@code @version} Javadoc tags were put on all classes, public or not. It 
was a little bit misleading
  * because non-public classes can be moved, split, merged, <i>etc.</i>, making 
the meaning of "since"
  * confusing. The rule is that {@code @since} should tell when a class was 
first available in public API,
- * which is not necessarily when it was first created. Finally, with the use 
of JPMS exporting only some
- * chosen packages, the presence/absence of those tags is a useful way to 
remind whether or not a class
- * in process of being modified is part of public API.
+ * which is not necessarily when it was first created. Finally, with the use 
of Java Modules exporting
+ * only some chosen packages, the presence/absence of those tags is a useful 
way to remind whether or
+ * not a class in process of being modified is part of public API.
  *
  * <h2>Limitations</h2>
  * This class does only a gross analysis. It may sometime be wrong.
diff --git 
a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularPublishing.java
 
b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularPublishing.java
index ba15612d7e..16a241fd7a 100644
--- 
a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularPublishing.java
+++ 
b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularPublishing.java
@@ -27,7 +27,7 @@ import org.apache.sis.buildtools.maven.Generator;
 
 /**
  * Extension to Gradle Maven publishing tasks.
- * The publication name must be the JPMS module name without the {@code 
org.apache.sis} prefix.
+ * The publication name must be the Java Module name without the {@code 
org.apache.sis} prefix.
  *
  * @author  Martin Desruisseaux (Geomatys)
  */
@@ -39,12 +39,12 @@ final class ModularPublishing {
 
     /**
      * The publications to handle as dependencies for other publications.
-     * Keys are JPMS module names.
+     * Keys are Java Module names.
      *
      * @todo It should not be a static field. But I didn't found another way
      *       to get the compilation results of other sub-projects.
      */
-    private static final Map<String,Dependency> publications = new HashMap<>();
+    private static final Map<String, Dependency> publications = new 
HashMap<>();
 
     /**
      * Creates a helper instance.
diff --git 
a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularTest.java 
b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularTest.java
index 5a53a41e0d..06c921da5d 100644
--- a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularTest.java
+++ b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/ModularTest.java
@@ -235,7 +235,7 @@ final class ModularTest extends Conventions {
         var mainpath = task.getClasspath().filter((path) -> 
!path.getName().equals("test"));
         task.jvmArgs(List.of("--module-path", mainpath.getAsPath()));
         /*
-         * JPMS options.
+         * Java Module options.
          */
         final var t = new ModularTest(task.getProject());
         task.getTestClassesDirs().forEach((dir) -> {
diff --git 
a/endorsed/src/org.apache.sis.referencing/test/org/apache/sis/referencing/operation/transform/DefaultMathTransformFactoryTest.java
 
b/endorsed/src/org.apache.sis.referencing/test/org/apache/sis/referencing/operation/transform/DefaultMathTransformFactoryTest.java
index 6929449861..1fa8ab86d5 100644
--- 
a/endorsed/src/org.apache.sis.referencing/test/org/apache/sis/referencing/operation/transform/DefaultMathTransformFactoryTest.java
+++ 
b/endorsed/src/org.apache.sis.referencing/test/org/apache/sis/referencing/operation/transform/DefaultMathTransformFactoryTest.java
@@ -90,7 +90,7 @@ public final class DefaultMathTransformFactoryTest extends 
TestCase {
     /**
      * Tests the correction for a Java 8 bug. In Java 8, {@link ServiceLoader} 
didn't supported
      * the usage of two {@link Iterator} instances before the first iteration 
is finished.
-     * This problem has been fixed with Java Platform Module System (JPMS) 
implementation.
+     * This problem has been fixed with Java Module (Jigsaw) implementation.
      */
     @Test
     public void testServiceLoaderIterator() {
diff --git 
a/endorsed/src/org.apache.sis.util/main/org/apache/sis/system/Reflect.java 
b/endorsed/src/org.apache.sis.util/main/org/apache/sis/system/Reflect.java
index 7d46a3d0ea..6396e8df4e 100644
--- a/endorsed/src/org.apache.sis.util/main/org/apache/sis/system/Reflect.java
+++ b/endorsed/src/org.apache.sis.util/main/org/apache/sis/system/Reflect.java
@@ -43,7 +43,7 @@ public final class Reflect implements 
Consumer<StackWalker.StackFrame> {
      * <p>The intent of this method is to ensure that {@link 
ServiceLoader#load(Class)} will find the
      * Apache SIS services even in an environment that defined an unsuitable 
context class loader.
      * Note that the call to {@code ServiceLoader.load(…)} must be done from 
the caller class.
-     * We cannot provide this convenience in this class because of JPMS 
encapsulation.</p>
+     * We cannot provide this convenience in this class because of Java Module 
encapsulation.</p>
      *
      * @return the context class loader if suitable, or another class loader 
otherwise.
      * @throws SecurityException if this method is not allowed to get the 
current thread

Reply via email to
diff --git 
a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/Dependency.java 
b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/Dependency.java
index 4bcec1da8c..a6b40aecae 100644
--- a/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/Dependency.java
+++ b/buildSrc/src/main/java/org/apache/sis/buildtools/gradle/Dependency.java
@@ -101,7 +101,7 @@ public final class Dependency {
     private final String group, name, version;
 
     /**
-     * Name of the JPMS module of the dependency, or {@code null} if 
unspecified.
+     * Name of the Java Module of the dependency, or {@code null} if 
unspecified.
      */
     public final String module;
 
@@ -139,9 +139,9 @@ public final class Dependency {
     }
 
     /**
      * Returns the name of the JPMS module of the dependency.
      *
      * @return JPMS module name, or {@code null} if unspecified.
      * @throws IOException if an I/O error occurred while reading the module 
description.
      */
     private String getModuleName() throws IOException {
@@ -185,15 +185,17 @@ public final class Dependency {
     }
 
     /**
      * Returns the JPMS dependencies of the given project.
      * Keys are JPMS module names are values are dependency descriptions.
      *
      * @param  project      the project for which to find dependencies.
-     * @param  subProjects  the sub-projects, which also need to be included 
as dependencies across JPMS modules.
+     * @param  subProjects  the sub-projects, which also need to be included 
as dependencies across Java Modules.
      * @return dependencies of the specified project.
      * @throws IOException if an I/O error occurred while reading the module 
description.
      */
-    public static Map<String,Dependency> jpms(final Project project, final 
Collection<Dependency> subProjects) throws IOException {
+    public static Map<String, Dependency> javaModules(final Project project, 
final Collection<Dependency> subProjects)
+            throws IOException
+    {
         final var dependencies = new HashMap<String,Dependency>();
         final var warnings     = new HashSet<String>();
         final var sources      = find(project);
@@ -139,9 +139,9 @@ public final class Dependency {
 
     /**
-     * Returns the name of the JPMS module of the dependency.
+     * Returns the name of the Java Module of the dependency.
      *
@@ -139,9 +139,9 @@ public final class Dependency {
      *
-     * @return JPMS module name, or {@code null} if unspecified.
+     * @return Java Module name, or {@code null} if unspecified.
      * @throws IOException if an I/O error occurred while reading the module 
description.
@@ -185,15 +185,17 @@ public final class Dependency {
 
     /**
-     * Returns the JPMS dependencies of the given project.
-     * Keys are JPMS module names are values are dependency descriptions.
+     * Returns the Java Module dependencies of the given project.
+     * Keys are Java Module names are values are dependency descriptions.
      *
      * @param  project      the project for which to find dependencies.
diff --git 
a/buildSrc/src/main/java/org/apache/sis/buildtools/maven/Generator.java 
b/buildSrc/src/main/java/org/apache/sis/buildtools/maven/Generator.java
index 0f6df6c1fc..0c85168434 100644
--- a/buildSrc/src/main/java/org/apache/sis/buildtools/maven/Generator.java
+++ b/buildSrc/src/main/java/org/apache/sis/buildtools/maven/Generator.java
@@ -102,7 +102,7 @@ public final class Generator {
     private final EnumMap<Element,String> info;
 
     /**
      * The required dependencies as JPMS module name.
      * Values are whether the dependency is optional.
      */
     private final Map<String,Boolean> requires;
@@ -260,7 +260,7 @@ public final class Generator {
      * Reads and rewrites the {@code pom.xml} file content.
      *
      * @param  project      the project to be published.
-     * @param  subProjects  the sub-projects, which also need to be included 
as dependencies across JPMS modules.
+     * @param  subProjects  the sub-projects, which also need to be included 
as dependencies across Java Modules.
      * @param  pub          configuration of the artifact to publish in Maven 
format.
      * @param  xml          provider of the original content, and where to 
write the result.
      */
@@ -271,7 +271,7 @@ public final class Generator {
         g.addLicensesIfEPSG();
         try {
             g.findUsedDependencies(pub.getArtifacts());
-            g.addDependencies(Dependency.jpms(project, subProjects));
+            g.addDependencies(Dependency.javaModules(project, subProjects));
         } catch (IOException e) {
             throw new UncheckedIOException(e);
         }
@@ -102,7 +102,7 @@ public final class Generator {
 
     /**
-     * The required dependencies as JPMS module name.
+     * The required dependencies as Java Module name.
      * Values are whether the dependency is optional.
      */